@@ -277,7 +277,8 @@ def process_download_requests():
                     try:
                         downloaded = set()
                         for i in range(len(files)):
-                            print_maybe("%s: downloading %s" % (relfile, files[i]))
+                            print_maybe("%s: downloading %s" %
+                                        (relfile, files[i]))
                             dest_file = download_file(files[i], sums[i])
                             if dest_file:
                                 command.append(dest_file)
@@ -291,7 +292,7 @@ def process_download_requests():
                         sys.stdout.flush()
                         result = subprocess.call(command)
                         if result:
-                            # There's no sense redownloading if the script fails
+                            # no sense redownloading if the script fails
                             permanent_failures.append(relfile)
                         else:
                             create_or_update_stampfile(stampfile)
