@@ -23,6 +23,8 @@
 #define UPGRADE_CHECKER PACKAGE_LIB_DIR"/update-notifier/apt-check"
 #define PACKAGE_SYSTEM_LOCKED PACKAGE_LIB_DIR"/update-notifier/package-system-locked"
 
+#define SHOW_UPDATES_APPINDICATOR FALSE
+
 typedef struct {
    const char *id;         // the action identifier
    const char *command;    // the command to execude
@@ -37,7 +39,7 @@ static action_t actions[] = {
    },
    {
       "show-updates",
-      "/usr/bin/update-manager --no-update",
+      "/usr/bin/update-manager",
       N_("Show Updates"),
    },
 };
@@ -210,6 +212,9 @@ update_apt_is_running(TrayApplet *ta, gboolean is_running)
    UpdateTrayAppletPrivate *priv = (UpdateTrayAppletPrivate*)ta->user_data;
    priv->apt_is_running = is_running;
 
+   if (!SHOW_UPDATES_APPINDICATOR)
+      return;
+
    if(is_running) {
 #ifdef HAVE_APP_INDICATOR
       // we can't do fancy stuff like the gray-out with app-indicator,
@@ -714,6 +719,9 @@ update_check (TrayApplet *ta)
       g_timeout_add_seconds(5, show_notification, ta);
    }
 
+   if (!SHOW_UPDATES_APPINDICATOR)
+      return TRUE;
+
    // if we are already visible, skip the rest
    if(tray_applet_ui_get_visible (ta))
       return TRUE;
