@@ -8,7 +8,6 @@ import random
 import shutil
 import socketserver
 import sys
-import time
 import tempfile
 import unittest
 
@@ -124,7 +123,8 @@ class ProcessDownloadRequestsTestCase(unittest.TestCase):
             file = os.path.join(package_data_downloader.DATADIR, file)
         before_st = os.stat(before)
         sec_ns = 10**9
-        os.utime(file, ns=(before_st.st_atime_ns - sec_ns, before_st.st_mtime_ns - sec_ns))
+        os.utime(file, ns=(before_st.st_atime_ns - sec_ns,
+                           before_st.st_mtime_ns - sec_ns))
 
     def test_hookfile_older_than_stampfile(self):
         # hook file older than stamp file nothing happens
